@@ -917,7 +917,6 @@ save_state (void)
 
   windows = g_slist_sort (windows, meta_display_stack_cmp);
   tmp = windows;
-  stack_position = 0;
 
   while (tmp != NULL)
     {
@@ -1775,6 +1774,11 @@ dialog_closed (GPid pid, int status, gpointer user_data)
     {
       finish_interact (shutdown);
     }
+  else
+    {
+      SmcInteractDone (session_connection, shutdown ? True : False);
+      save_yourself_possibly_done (shutdown, FALSE);
+    }
 }
 
 static void
