@@ -64,11 +64,11 @@ struct _MetaWorkspace
   GList  *list_containing_self;
 
   MetaRectangle work_area_screen;
-  MetaRectangle *work_area_xinerama;
+  MetaRectangle *work_area_monitor;
   GList  *screen_region;
-  GList  **xinerama_region;
+  GList  **monitor_region;
   GList  *screen_edges;
-  GList  *xinerama_edges;
+  GList  *monitor_edges;
   GSList *all_struts;
   guint work_areas_invalid : 1;
 
@@ -94,14 +94,14 @@ GList*         meta_workspace_list_windows  (MetaWorkspace *workspace);
 void meta_workspace_invalidate_work_area (MetaWorkspace *workspace);
 
 
-void meta_workspace_get_work_area_for_xinerama  (MetaWorkspace *workspace,
-                                                 int            which_xinerama,
-                                                 MetaRectangle *area);
-void meta_workspace_get_work_area_all_xineramas (MetaWorkspace *workspace,
-                                                 MetaRectangle *area);
-GList* meta_workspace_get_onscreen_region       (MetaWorkspace *workspace);
-GList* meta_workspace_get_onxinerama_region     (MetaWorkspace *workspace,
-                                                 int            which_xinerama);
+void meta_workspace_get_work_area_for_monitor  (MetaWorkspace *workspace,
+                                                int            which_monitor,
+                                                MetaRectangle *area);
+void meta_workspace_get_work_area_all_monitors (MetaWorkspace *workspace,
+                                                MetaRectangle *area);
+GList* meta_workspace_get_onscreen_region      (MetaWorkspace *workspace);
+GList* meta_workspace_get_onmonitor_region     (MetaWorkspace *workspace,
+                                                int            which_monitor);
 
 void meta_workspace_focus_default_window (MetaWorkspace *workspace,
                                           MetaWindow    *not_this_one,
@@ -113,7 +113,3 @@ MetaWorkspace* meta_workspace_get_neighbor (MetaWorkspace      *workspace,
 const char* meta_workspace_get_name (MetaWorkspace *workspace);
 
 #endif
-
-
-
-
